<?php

namespace SM\Service;

use SM\Factory\CdaFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CdaService
{

    protected $CdaFactory;
    protected $Environment;
    protected $newCode;


    public function __construct(EntityManager $entityManager, CdaFactory $CdaFactory, Environment $Environment, NewCode $newCode)
    {
        $this->CdaFactory = $CdaFactory;
        $this->connection                   = $entityManager->getConnection();
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function getCda($params)
    {
        $dataParams = array(
            "CDFUNC"            => $params["CDFUNC"],
            "CDFILIAL"          => $params["CDFILIAL"],
            "CDEMPRESA"         => $params["CDEMPRESA"],
            "NRORG"             => $params["NRORG"],
            "CDOPERADOR"        => $params["CDOPERADOR"],
            "DTINICIALPERIODO"  => $params["DTINICIALPERIODO"],
            "DTFINALPERIODO"    => $params["DTFINALPERIODO"]
        );
        return $this->CdaFactory->getCda($dataParams);
    }

    public function getFuncionarios()
    {
        return $this->CdaFactory->getFuncionarios();
    }

    public function getFuncionarioLogado()
    {
        $cdoperador = $this->Environment->getCdOperador();
        return $cdoperador;
    } 

    public function getPermissaoOperadorCda()
    {
        $cdoperador = $this->Environment->getCdOperador();
        $nrorg = $this->Environment->getNrorg();

        $dataParams = array(
            "CDOPERADOR"    => $cdoperador,
            "NRORG"         => $nrorg
        );
        return $this->CdaFactory->getPermissaoOperadorCda($dataParams);
    }

    public function getPeriodoApuraPonto()
    {
        return $this->CdaFactory->getPeriodoApuraPonto();
    }

    public function getClienteCda()
    {
        return $this->CdaFactory->getClienteCda();
    }

    public function getRepresentante($params)
    {
        $dataParams = array(
            "CDCLIENTE" => isset($params["CDCLIENTE"])? $params["CDCLIENTE"] : null
        );
        return $this->CdaFactory->getRepresentante($dataParams);
    }

    public function getPropostaCda($params)
    {
        $nrorg = $this->Environment->getNrorg();
        $dataParams = array(
            "CDCLIENTE" => isset($params["CDCLIENTE"])? $params["CDCLIENTE"] : null,
            "CDFUNC"    => isset($params["CDFUNC"])? $params["CDFUNC"] : null,
            "NRORG"     => $nrorg
        );
        return $this->CdaFactory->getPropostaCda($dataParams);
    }

    public function getProjetoOperadorCliente($params)
    {
        $cdoperador = $this->Environment->getCdOperador();
        $nrorg = $this->Environment->getNrorg();

        $dataParams = array(
            "CDCLIENTE"     => isset($params["CDCLIENTE"])? $params["CDCLIENTE"] : null,
            "CDOPERADOR"    => $cdoperador,
            "NRORG"         => $nrorg,
        );
        return $this->CdaFactory->getProjetoOperadorCliente($dataParams);
    }

    public function getTipoAtividadeCda($params)
    {
        $dataParams = array(
            "CDCLIENTE"     => isset($params["CDCLIENTE"])? $params["CDCLIENTE"] : null,
            "NRORG"         => isset($params["NRORG"])? $params["NRORG"] : null,
            "CDFUNC"        => isset($params["CDFUNC"])? $params["CDFUNC"] : null,
            "NRVERPROPFAS"  => isset($params["NRVERPROPFAS"])? $params["NRVERPROPFAS"] : null,
            "NRPROPOSFAS"   => isset($params["NRPROPOSFAS"])? $params["NRPROPOSFAS"] : null,
            "DTSERVPREST"   => isset($params["DTSERVPREST"])? $params["DTSERVPREST"] : null
        );

        return $this->CdaFactory->getTipoAtividadeCda($dataParams);
    }

    public function getProspectCda()
    {
        return $this->CdaFactory->getProspectCda();
    }

    public function getInterlocutorProspectCda($params)
    {
        $dataParams = array(
            "CDPROSPECT" => isset($params["CDPROSPECT"])? $params["CDPROSPECT"] : null
        );
        return $this->CdaFactory->getInterlocutorProspectCda($dataParams);
    }
    
    public function getInterlocutorClienteCda($params)
    {
        $dataParams = array(
            "CDCLIENTE" => isset($params["CDCLIENTE"])? $params["CDCLIENTE"] : null,
        );
        return $this->CdaFactory->getInterlocutorClienteCda($dataParams);
    }

    public function getLicencaUsoCda($params)
    {
        $dataParams = array(
            "CDCLIENTE" => isset($params["CDCLIENTE"])? $params["CDCLIENTE"] : null,
        );
        return $this->CdaFactory->getLicencaUsoCda($dataParams);
    }

    public function getJustHorasNaoFaturadasCda()
    {
        return $this->CdaFactory->getJustHorasNaoFaturadasCda();
    }

    public function getMotivoEvoContCda()
    {
        return $this->CdaFactory->getMotivoEvoContCda();
    }

    public function getContatosParceiroCda($params)
    {
        $dataParams = array(
            "NRPARCNEGOCIO" => isset($params["NRPARCNEGOCIO"])? $params["NRPARCNEGOCIO"] : null,
        );
        return $this->CdaFactory->getContatosParceiroCda($dataParams);
    }

    public function getMotivoContatoCda()
    {
        return $this->CdaFactory->getMotivoContatoCda();
    }

    public function getSistemaCda()
    {
        return $this->CdaFactory->getSistemaCda();
    }

    public function getMotivoJustificativaCda()
    {
        return $this->CdaFactory->getMotivoJustificativaCda();
    }

    public function getMotivoAfastamentoInssCda()
    {
        return $this->CdaFactory->getMotivoAfastamentoInssCda();
    }

    public function getServParticipantesCda()
    {
        return $this->CdaFactory->getServParticipantesCda();
    }

    public function gravaContatoCDA($params) 
    {
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();

        try{
            if(is_null($params["NRCONTATO"]) || $params["NRCONTATO"] == '') {
                $novoCodigo = $this->newCode->getCodeByTableName("NRSEQCONTATO", $nrorg, 1, 10, true);
                $idstatuscont = 'A';
                $dthrcontato = $params["DTSERVPREST"];
                $idtpcontato = ($params["IDSERVPREST"] == 'RELACIONAMENTO_CLIENTE') ? 'C' : 'P';
                $dsrefecont = ($params["IDSERVPREST"] == 'RELACIONAMENTO_CLIENTE') ? "Relacionamento com o cliente" : "Visita a Prospect";
                $cdopercont = $cdoperador;

                // Gravação na tabela CONTATO
                $novoContato = array (
                    "NRCONTATO"         => $novoCodigo,
                    "CDMOTICONT"        => $params["CDMOTICONT"],
                    "CDCLIENTE"         => $params["CDCLIENTE"],
                    "CDPROSPECT"        => $params["CDPROSPECT"],
                    "DTHRCONTATO"       => $dthrcontato,
                    "DSREFECONT"        => $dsrefecont,
                    "IDSTATUSCONT"      => $idstatuscont,
                    "IDTPCONTATO"       => $idtpcontato,
                    "CDSISTEMA"         => $params["CDSISTEMA"],
                    "CDOPERCONT"        => $cdopercont,
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERINCLUSAO"    => $cdopercont,
                    "NRPARCNEGOCIO"     => $params["NRPARCNEGOCIO"],
                    "NRSEQCONTATO"      => $novoCodigo,
                );

                $this->CdaFactory->inserirContatoCda($novoContato);

            } else {
                $dataParams = array(
                    "NRSEQCONTATO" => $params["NRCONTATO"],
                );
                $contato = $this->CdaFactory->getContatoCda($dataParams);
                $idstatuscont = $contato["data"][0]["IDSTATUSCONT"];
                $dthrcontato = $contato["data"][0]["DTHRCONTATO"];
                $idtpcontato = $contato["data"][0]["IDTPCONTATO"];
                $dsrefecont = $contato["data"][0]["DSREFECONT"];
                $cdopercont = $contato["data"][0]["CDOPERCONT"];
            }

            if (isset($novoCodigo)) {
                $parametro = array(
                    "NRSEQCONTATO" => $novoContato["NRCONTATO"],
                );
            } else {
                $parametro = array(
                    "NRSEQCONTATO" => $params["NRCONTATO"],
                );
            }

            $dadosContato = $this->CdaFactory->getContatoCda($parametro);

            //Gravação na tabela EVOCONT

            if ($params["IDSERVPREST"] == 'RELACIONAMENTO_CLIENTE') {
                
                $dataInteclie = array(
                    "CDCLIENTE"     => $params["CDCLIENTE"],
                    "CDINTECLIE"    => $params["CDINTECLIE"],
                    "NRORG"         => $nrorg
                );

                $nrrelacionaparc = $this->CdaFactory->getNrrelacionaparcCliente($dataInteclie);
            } else {

                $dataInteprosp = array(
                    "CDPROSPECT"    => $params["CDPROSPECT"],
                    "CDINTEPROS"    => $params["CDINTEPROS"],
                    "NRORG"         => $nrorg
                );

                $nrrelacionaparc = $this->CdaFactory->getNrrelacionaparcProspect($dataInteprosp);
            }

            if(is_null($params["DTHREVOLCONT"]) || $params["DTHREVOLCONT"] == '') {
                $cdtipocont = '60';  // '60' - Visita
                $idsenevocont = 'S'; // 'S' - Saída
                $idtpevolcont = ($params["IDSERVPREST"] == 'RELACIONAMENTO_CLIENTE') ? 'C' : 'P';
                $cdfasecont = '036'; // '036' - Visita comercial
                $idageevocont = 'N';
                $dthrinclevocont = $params["DTSERVPREST"];
                $idanexoevolcont = 'N';
            }

            $paramsEvolcont = array(
                'NRORG'        => $nrorg,
                'NRCONTATO'    => $dadosContato["data"][0]["NRSEQCONTATO"]        
            );
            
            $evolcontprox = $this->CdaFactory->consultaProxSequencialEvolCont($paramsEvolcont);

            $nrseqevolcon = $evolcontprox["data"][0]['NRSEQEVOLCON'];

            $novoCodigoNrseqevolcont = $this->newCode->getCodeByTableName("EVOLCONT", $nrorg, 1, 10, true);
            
            $novaEvocont = array (
                "NRCONTATO"         => $dadosContato["data"][0]["NRSEQCONTATO"],
                "CDTIPOCONT"        => $cdtipocont,
                "CDPROSPECT"        => $params["CDPROSPECT"],
                "CDINTEPROS"        => $params["CDINTEPROS"],
                "CDCLIENTE"         => $params["CDCLIENTE"],
                "CDINTECLIE"        => $params["CDINTECLIE"],
                "IDSENEVOCONT"      => $idsenevocont,
                "IDTPEVOLCONT"      => $idtpevolcont,
                "DSEVOLCONT"        => $params["DSEVOLCONT"],
                "IDDESCPROT"        => 'N',
                "CDFASECONT"        => $cdfasecont,
                "IDAGEEVOCONT"      => $idageevocont,
                "CDOPEREVOL"        => $cdoperador,
                "NRSEQEVOLCON"      => $nrseqevolcon,
                "CDMOTIEVOCON"      => $params["CDMOTIEVOCON"],
                "NRORG"             => $nrorg,
                "NRORGINCLUSAO"     => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "NRORGULTATU"       => $nrorg,
                "CDOPERULTATU"      => $cdoperador,
                "NRRELACIONAPARC"   => isset(["data"][0]["NRRELACIONAPARC"])? ["data"][0]["NRRELACIONAPARC"] : null,
                "IDANEXOEVOLCONT"   => $idanexoevolcont,
                "TXEVOLCONT"        => $params["DSEVOLCONT"],
                "IDATIVO"           => 'S',
                "NRSEQEVOLCONT"     => $novoCodigoNrseqevolcont,
                "NRSEQCONTATO"      => $dadosContato["data"][0]["NRSEQCONTATO"],
                "IDGERAFATURA"      => 'NAO',
                "IDEVOLPUBLICO"     => 'S',
                "IDRESPNOTA"        => 'R',
                "IDEVOLINTERNA"     => 'S'
            );

            $this->CdaFactory->inserirEvoContCda($novaEvocont);

            $parametroContatoEvolcont = array(
                "NRSEQCONTATO"  => $dadosContato["data"][0]["NRSEQCONTATO"],
                "NRSEQEVOLCONT" => $novoCodigoNrseqevolcont,
            );

            $dadosContatoEvolcont = $this->CdaFactory->getEvoltcontCda($parametroContatoEvolcont);

            return $dadosContatoEvolcont;

        } catch (\Exception $e) {
            throw $e;
        }
        
    }

    public function consultaProxNrServPrest($params)
    {
        $nrorg = $this->Environment->getNrorg();
        
        $dataParams = array(
            "NRORG"         => $nrorg,
            "CDEMPRESA"     => $params["CDEMPRESA"],
            "CDFUNC"        => $params["CDFUNC"],
            "CDCLIENTE"     => $params["CDCLIENTE"],
            "DTSERVPREST"   => $params["DTSERVPREST"],
        );

        return $this->CdaFactory->consultaProxNrServPrest($dataParams);
    }

    private function getDefaultFieldValues($idservprest) {
        $nrorg = $this->Environment->getNrorg();
        $defaultvalues = array(
            "NRORG" => $nrorg
        );
        
        if($idservprest == "ATIVIDADE_INTERNA" || 
           $idservprest == "FALTA_JUSTIFICADA" || 
           $idservprest == "FALTA_NAO_JUSTIFICADA" || 
           $idservprest == "AFASTAMENTO_INSS" || 
           $idservprest == "FERIAS" ||
           $idservprest == "VISITA_PROSPECT" ||
           $idservprest == "RELACIONAMENTO_CLIENTE") {
            
            $defaultvalues["CDTIPOSERV"] = "030";
            if($idservprest != "RELACIONAMENTO_CLIENTE") {
                $defaultvalues["CDCLIENTE"]  = "J26269316000177";
            }
        }
        
        return $defaultvalues;
    }

    public function inserirAtividadeCda($parametros)
    {
        
        $this->connection->beginTransaction();

        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();

        try {
            if(is_null($parametros["NRSERVPREST"]) || $parametros["NRSERVPREST"] == '' || $parametros["NRSERVPREST"] == '00000') {
                if(is_null($parametros["CDCLIENTE"]) || $parametros["CDCLIENTE"] == '') {
                    $clienteDefault = $this->getDefaultFieldValues($parametros["IDSERVPREST"]);
                    
                    $dataConsultaProxNrServPrest= array(
                        "CDEMPRESA"     => $parametros["CDEMPRESA"],
                        "CDFUNC"        => $parametros["CDFUNC"],
                        "CDCLIENTE"     => $clienteDefault["CDCLIENTE"],
                        "DTSERVPREST"   => $parametros["DTSERVPREST"],
                    );

                    $nrservprest = $this->consultaProxNrServPrest($dataConsultaProxNrServPrest);
                }

                if ($parametros["IDSERVPREST"] == 'ATIVIDADE_CLIENTE'|| $parametros["IDSERVPREST"] == 'RELACIONAMENTO_CLIENTE') {

                    $dataConsultaProxNrServPrest= array(
                        "CDEMPRESA"     => $parametros["CDEMPRESA"],
                        "CDFUNC"        => $parametros["CDFUNC"],
                        "CDCLIENTE"     => $parametros["CDCLIENTE"],
                        "DTSERVPREST"   => $parametros["DTSERVPREST"]
                    );

                    $nrservprest = $this->consultaProxNrServPrest($dataConsultaProxNrServPrest);
                }
            
                if ($parametros["IDSERVPREST"] == 'ATIVIDADE_CLIENTE') {

                    $dadosAgendaServ = $this->getNrservcontAndNrseqageserv($parametros);

                    if (count($dadosAgendaServ) > 0) {
                        $dataParamsAgendaServ = array(
                            "NRPROPOSFAS"   => $parametros["NRPROPOSFAS"],
                            "NRVERPROPFAS"  => $parametros["NRVERPROPFAS"],
                            "CDTIPOSERV"    => $parametros["CDTIPOSERV"],
                            "NRSERVCONT"    => $dadosAgendaServ[0]["NRSERVCONT"],
                            "NRSEQAGESERV"  => $dadosAgendaServ[0]["NRSEQAGESERV"]
                        );  
                    } else {
                        throw new \Exception('mensagem de erro');
                    }

                    $dataParamsAtivCli = array(
                        "NRMOTIVOEXCEFREQ"    => $parametros["NRMOTIVOEXCEFREQ"],
                        "CDEMPRESA"           => $parametros["CDEMPRESA"],
                        "CDFUNC"              => $parametros["CDFUNC"],
                        "CDCLIENTE"           => $parametros["CDCLIENTE"],
                        "DTSERVPREST"         => $parametros["DTSERVPREST"],
                        "DSREFERENCIA"        => $parametros["DSREFERENCIA"],
                        "IDSITSERVPREST"      => $parametros["IDSITSERVPREST"],
                        "NRORG"               => $nrorg,
                        "NRORGINCLUSAO"       => $nrorg,
                        "NRORGULTATU"         => $nrorg,
                        "DTINCLUSAO"          => null,
                        "DTULTATU"            => $parametros["DTULTATU"],
                        "CDOPERINCLUSAO"      => $cdoperador,
                        "CDOPERULTATU"        => $cdoperador,
                        "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                        "IDRESUAUDITCSA"      => 'NR',
                        "IDSERVPREST"         => $parametros["IDSERVPREST"],
                        "IDASSINATURACLIENTE" => 'N',
                        "IDORIGINALENTREGUE"  => 'N',
                        "IDASSINATURACLIENTE" => 'N',
                        "IDATIVO"             => 'S',
                        "CDINTECLIE"          => $parametros["CDINTECLIE"],
                        "NMINTCLIENTE"        => $parametros["NMINTCLIENTE"],
                        "NRLICENCAUSO"        => null,
                        "CDPROJETO"           => null,
                        "NRSEQUCHT"           => null,
                        "NRCONTATO"           => null,
                        "DTHREVOLCONT"        => null,
                        "DTENTRADA"           => null,
                        "CDFILIAL"            => null
                    );

                    $dataAtividadeCliente = array_merge($dataParamsAgendaServ, $dataParamsAtivCli);
                    $this->CdaFactory->inserirAtividadeCda($dataAtividadeCliente);

                    $participantes = $parametros["PARTICIPANTES"];

                    foreach ($participantes as $participante) {
                        $novoCodigo = $this->newCode->getCodeByTableName("SERVPRESTPARTICIP", $nrorg, 1, 10, true);
                        $dados = array (
                            "NRSERVPRESTPARTICIP" => $novoCodigo,
                            "DSNOMEPARTICIP"      => $participante["DSNOMEPARTICIP"],
                            "DSSETORPARTICIP"     => $participante["DSSETORPARTICIP"],
                            "CDEMPRESA"           => $parametros["CDEMPRESA"],
                            "CDFUNC"              => $parametros["CDFUNC"],
                            "CDCLIENTE"           => $parametros["CDCLIENTE"],
                            "DTSERVPREST"         => $parametros["DTSERVPREST"],
                            "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                            "IDATIVO"             => 'S',
                            "NRORG"               => $nrorg,
                            "NRORGINCLUSAO"       => $nrorg,
                            "CDOPERINCLUSAO"      => $cdoperador
                        );
                        $this->CdaFactory->inserirParticipantesCda($dados);
                    }
                }

                if($parametros["IDSERVPREST"] == 'VISITA_PROSPECT' || $parametros["IDSERVPREST"] == 'RELACIONAMENTO_CLIENTE') {
                    
                    $tiposervdefault = $this->getDefaultFieldValues($parametros["IDSERVPREST"]);
                    
                    $dataParamsContato = array(
                        "IDSERVPREST"   => $parametros["IDSERVPREST"],
                        "CDCLIENTE"     => isset($clienteDefault["CDCLIENTE"]) ? $clienteDefault["CDCLIENTE"] : $parametros["CDCLIENTE"],
                        "CDINTECLIE"    => $parametros["CDINTECLIE"],
                        "CDPROSPECT"    => $parametros["CDPROSPECT"],
                        "CDINTEPROS"    => $parametros["CDINTEPROS"],
                        "CDMOTICONT"    => $parametros["CDMOTICONT"],
                        "CDMOTIEVOCON"  => $parametros["CDMOTICONT"],
                        "CDSISTEMA"     => $parametros["CDSISTEMA"],
                        "CDTIPOSERV"    => $tiposervdefault["CDTIPOSERV"],
                        "NRCONTATO"     => $parametros["NRCONTATO"],
                        "NRPARCNEGOCIO" => $parametros["NRPARCNEGOCIO"],
                        "DTHREVOLCONT"  => $parametros["DTHREVOLCONT"],
                        "DTSERVPREST"   => $parametros["DTSERVPREST"],
                        "DSEVOLCONT"    => $parametros["DSEVOLCONT"]
                    );

                    $dadosContato = $this->gravaContatoCDA($dataParamsContato);

                    $dataParams = array(
                        "NRMOTIVOEXCEFREQ"    => null,
                        "CDEMPRESA"           => $parametros["CDEMPRESA"],
                        "CDFUNC"              => $parametros["CDFUNC"],
                        "CDCLIENTE"           => isset($clienteDefault["CDCLIENTE"])? $clienteDefault["CDCLIENTE"] : $parametros["CDCLIENTE"],
                        "DTSERVPREST"         => $parametros["DTSERVPREST"],
                        "DSREFERENCIA"        => $parametros["DSREFERENCIA"],
                        "IDSITSERVPREST"      => $parametros["IDSITSERVPREST"],
                        "NRORG"               => $nrorg,
                        "NRORGINCLUSAO"       => $nrorg,
                        "NRORGULTATU"         => $nrorg,
                        "DTINCLUSAO"          => $parametros["DTSERVPREST"],
                        "DTULTATU"            => $parametros["DTULTATU"],
                        "CDOPERINCLUSAO"      => $cdoperador,
                        "CDOPERULTATU"        => $cdoperador,
                        "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                        "IDRESUAUDITCSA"      => 'NR',
                        "IDSERVPREST"         => $parametros["IDSERVPREST"],
                        "IDASSINATURACLIENTE" => 'N',
                        "IDORIGINALENTREGUE"  => 'N',
                        "IDASSINATURACLIENTE" => 'N',
                        "IDATIVO"             => 'S',
                        "CDINTECLIE"          => $parametros["CDINTECLIE"],
                        "CDPROSPECT"          => $parametros["CDPROSPECT"],
                        "CDINTEPROS"          => $parametros["CDINTEPROS"],
                        "CDTIPOSERV"          => $tiposervdefault["CDTIPOSERV"],
                        "NMINTCLIENTE"        => $parametros["NMINTCLIENTE"],
                        "NRLICENCAUSO"        => null,
                        "CDPROJETO"           => null,
                        "NRSEQUCHT"           => null,
                        "NRCONTATO"           => isset($dadosContato["data"][0]["NRSEQCONTATO"])? $dadosContato["data"][0]["NRSEQCONTATO"] : $parametros["NRCONTATO"],
                        "DTHREVOLCONT"        => $dadosContato["data"][0]["DTHREVOLCONT"],
                        "DTENTRADA"           => null,
                        "NRPROPOSFAS"         => null,
                        "NRVERPROPFAS"        => null,
                        "NRSERVCONT"          => null,
                        "NRSEQAGESERV"        => null,
                        "CDFILIAL"            => null
                    );
                    
                    // Grava novo lançamento de atividade registrando o contato. Usado nas atividades relacionadas a Vista a prospect e Relacionamento com o cliente.
                    $this->CdaFactory->inserirAtividadeCdaComContato($dataParams);

                    $participantes = $parametros["PARTICIPANTES"];

                    foreach ($participantes as $participante) {
                        $novoCodigo = $this->newCode->getCodeByTableName("SERVPRESTPARTICIP", $nrorg, 1, 10, true);
                        $dados = array (
                            "NRSERVPRESTPARTICIP" => $novoCodigo,
                            "DSNOMEPARTICIP"      => $participante["DSNOMEPARTICIP"],
                            "DSSETORPARTICIP"     => $participante["DSSETORPARTICIP"],
                            "CDEMPRESA"           => $parametros["CDEMPRESA"],
                            "CDFUNC"              => $parametros["CDFUNC"],
                            "CDCLIENTE"           => $parametros["CDCLIENTE"],
                            "DTSERVPREST"         => $parametros["DTSERVPREST"],
                            "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                            "IDATIVO"             => 'S',
                            "NRORG"               => $nrorg,
                            "NRORGINCLUSAO"       => $nrorg,
                            "CDOPERINCLUSAO"      => $cdoperador
                        );
                        $this->CdaFactory->inserirParticipantesCda($dados);
                    }
                }

                if ($parametros["IDSERVPREST"] == 'ATIVIDADE_INTERNA' || $parametros["IDSERVPREST"] == 'FERIAS') {
                    $dataParams= array(
                        "CDEMPRESA"           => $parametros["CDEMPRESA"],
                        "CDFUNC"              => $parametros["CDFUNC"],
                        "CDCLIENTE"           => $clienteDefault["CDCLIENTE"],
                        "DTSERVPREST"         => $parametros["DTSERVPREST"],
                        "CDTIPOSERV"          => $clienteDefault["CDTIPOSERV"],
                        "DSREFERENCIA"        => $parametros["DSREFERENCIA"],
                        "IDSITSERVPREST"      => $parametros["IDSITSERVPREST"],
                        "NRORG"               => $nrorg,
                        "NRORGINCLUSAO"       => $nrorg,
                        "NRORGULTATU"         => $nrorg,
                        "CDOPERINCLUSAO"      => $parametros["CDOPERINCLUSAO"],
                        "CDOPERULTATU"        => $parametros["CDOPERINCLUSAO"],
                        "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                        "IDRESUAUDITCSA"      => 'NR',
                        "IDSERVPREST"         => $parametros["IDSERVPREST"],
                        "IDASSINATURACLIENTE" => 'N',
                        "IDORIGINALENTREGUE"  => 'N',
                        "IDASSINATURACLIENTE" => 'N',
                        "IDATIVO"             => 'S',
                        "IDSITSERVPREST"      => 'P',
                    );
                    
                    $this->CdaFactory->inserirAtividadeInternaCda($dataParams);
                }

                if ($parametros["IDSERVPREST"] == 'FALTA_JUSTIFICADA' || $parametros["IDSERVPREST"] == 'AFASTAMENTO_INSS') {
                    $dataParams= array(
                        "CDEMPRESA"           => $parametros["CDEMPRESA"],
                        "CDFUNC"              => $parametros["CDFUNC"],
                        "CDCLIENTE"           => $clienteDefault["CDCLIENTE"],
                        "DTSERVPREST"         => $parametros["DTSERVPREST"],
                        "CDTIPOSERV"          => $clienteDefault["CDTIPOSERV"],
                        "DSREFERENCIA"        => $parametros["DSREFERENCIA"],
                        "IDSITSERVPREST"      => $parametros["IDSITSERVPREST"],
                        "NRORG"               => $nrorg,
                        "NRORGINCLUSAO"       => $nrorg,
                        "NRORGULTATU"         => $nrorg,
                        "CDOPERINCLUSAO"      => $parametros["CDOPERINCLUSAO"],
                        "CDOPERULTATU"        => $parametros["CDOPERINCLUSAO"],
                        "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                        "IDRESUAUDITCSA"      => 'NR',
                        "IDSERVPREST"         => $parametros["IDSERVPREST"],
                        "IDASSINATURACLIENTE" => 'N',
                        "IDORIGINALENTREGUE"  => 'N',
                        "IDASSINATURACLIENTE" => 'N',
                        "IDATIVO"             => 'S',
                        "IDSITSERVPREST"      => 'P',
                        "NRMOTIVOEXCEFREQ"    => $parametros["NRMOTIVOEXCEFREQ"]
                    );
                    
                    $this->CdaFactory->inserirAtividadeComJustificativaCda($dataParams);
                }

                if ($parametros["IDSERVPREST"] == 'FALTA_NAO_JUSTIFICADA') {
                    $dataParams= array(
                        "CDEMPRESA"           => $parametros["CDEMPRESA"],
                        "CDFUNC"              => $parametros["CDFUNC"],
                        "CDCLIENTE"           => $clienteDefault["CDCLIENTE"],
                        "DTSERVPREST"         => $parametros["DTSERVPREST"],
                        "CDTIPOSERV"          => $clienteDefault["CDTIPOSERV"],
                        "DSREFERENCIA"        => $parametros["DSREFERENCIA"],
                        "IDSITSERVPREST"      => $parametros["IDSITSERVPREST"],
                        "NRORG"               => $nrorg,
                        "NRORGINCLUSAO"       => $nrorg,
                        "NRORGULTATU"         => $nrorg,
                        "CDOPERINCLUSAO"      => $parametros["CDOPERINCLUSAO"],
                        "CDOPERULTATU"        => $parametros["CDOPERINCLUSAO"],
                        "NRSERVPREST"         => $nrservprest["data"][0]["NRSERVPREST"],
                        "IDRESUAUDITCSA"      => 'NR',
                        "IDSERVPREST"         => $parametros["IDSERVPREST"],
                        "IDASSINATURACLIENTE" => 'N',
                        "IDORIGINALENTREGUE"  => 'N',
                        "IDASSINATURACLIENTE" => 'N',
                        "IDATIVO"             => 'S',
                        "IDSITSERVPREST"      => 'P',
                        "NRMOTIVOEXCEFREQ"    => $parametros["NRMOTIVOEXCEFREQ"]
                    );
                    
                    //Pendente calcular as faltas

                    $this->CdaFactory->inserirAtividadeComJustificativaCda($dataParams);
                }
            } else {
                //implementar atualização das informações de uma atividade.
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getNrservcontAndNrseqageserv($params){
        $nrorg = $this->Environment->getNrorg();

        $dataParams = array(
            'NRORG'        => $nrorg, 
            'NRPROPOSFAS'  => $params["NRPROPOSFAS"],
            'NRVERPROPFAS' => $params["NRVERPROPFAS"], 
            'CDTIPOSERV'   => $params["CDTIPOSERV"], 
            'DTSERVPREST'  => $params["DTSERVPREST"], 
            'CDEMPRESA'    => $params["CDEMPRESA"], 
            'CDFUNC'       => $params["CDFUNC"], 
        );

        return $this->CdaFactory->getNrservcontAndNrseqageserv($dataParams);
    }

    public function gerarDocumentoCda(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrservprest  = $row["NRSERVPREST"];
            $ideservprest = $row["IDSERVPREST"];
            $nrorg           = $row["NRORG"];
            $cdcliente      = $row["CDCLIENTE"];
            $cdoperador   = $row["CDOPERADOR"];
            $caminhoArquivos = $this->documentoService->gerarDocumentoProposta($nrseqorcamento, $nrtipoorcamento, $nrorg, $idSituacao, $idpermitedocx);
            
            if (count($caminhoArquivos) > 0) {
                $escopos = "";
                foreach ($caminhoArquivos as $arq) {
                    $retorno[] = $arq["CAMINHO"];
                    
                    if ($arq["NMTIPOORCAMENTO"])
                        $escopos = $escopos . ($escopos == "" ? "" : ", ") . $arq["NMTIPOORCAMENTO"]; 
                }
                
                if (count($retorno) > 0) 
                    $response->addDataSet(new DataSet("documentos", array("links" => $retorno)));
                else 
                    throw new \Exception("Falha ao anexar o(s) documento(s) no FileServer.");
            } else {
                throw new \Exception("Falha ao gerar o(s) documento(s).");
            }
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
