<?php

namespace SM\Service;

use SM\Factory\Sm00050002QuantidadeMaximaParcelasPerfilAcessoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00050002QuantidadeMaximaParcelasPerfilAcessoService
{
    protected $connection;
    protected $qtdMaxParcelasFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00050002QuantidadeMaximaParcelasPerfilAcessoFactory $qtdMaxParcelasFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->qtdMaxParcelasFactory = $qtdMaxParcelasFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getQuantidadeMaximaParcelasPerfilAcesso()
    {
        return $this->qtdMaxParcelasFactory->getQuantidadeMaximaParcelasPerfilAcesso();
    }

    public function saveQtdMaximaParcelasPerfilAcesso($parametros)
    {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        $this->connection->beginTransaction();

        $paramsaux = array(
            "NRPERFILACESSO" => $parametros[0]['NRPERFILACESSO'],
            "NRQTPARCMAXPERFACESS" => $parametros[0]['NRQTPARCMAXPERFACESS']
        );
        
        $dados = $this->qtdMaxParcelasFactory->validaQtdMaximaParcelasPerfilAcesso($paramsaux);

        try {
            foreach ($parametros as $chave => $parcelas) {
                if ($parcelas["NRQTPARCMAXPERFACESS"] == 0) {
                    $nrqtparcemaximaperfilacesso = $this->newCode->getCodeByTableName("FCT_QTPARCMAXPERFACESS", $nrorg, 1, 10, true);
                    $parametros = array(
                    "NRQTPARCMAXPERFACESS"   => $nrqtparcemaximaperfilacesso,
                    "NRPERFILACESSO"         => $parcelas['NRPERFILACESSO'],
                    "QTPARCMAXPERFACESS"     => $parcelas['QTPARCMAXPERFACESS'],
                    "NRORG"                  => $nrorg,
                    "IDATIVO"                => "S",
                    "NRORGINCLUSAO"          => $nrorg,
                    "CDOPERINCLUSAO"         => $cdoperador
                    );
                    if ($dados[0]["QTD"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->qtdMaxParcelasFactory->insertQtdMaximaParcelasPerfilAcesso($parametros);
                    }
                } else {
                    $parametros = array(
                    "NRQTPARCMAXPERFACESS"     => $parcelas['NRQTPARCMAXPERFACESS'],
                    "NRPERFILACESSO"             => $parcelas['NRPERFILACESSO'],
                    "QTPARCMAXPERFACESS"       => $parcelas['QTPARCMAXPERFACESS'],
                    "NRORG"                  => $nrorg,
                    "IDATIVO"                => "S",
                    "NRORGINCLUSAO"          => $nrorg,
                    "CDOPERINCLUSAO"         => $cdoperador,
                    );
                    if ($dados[0]["QTD"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->qtdMaxParcelasFactory->updateQtdMaximaParcelasPerfilAcesso($parametros);
                    }
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteQtdMaximaParcelasPerfilAcesso($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $parcelas) {
                $dataParam = array( "NRQTPARCMAXPERFACESS" => $parcelas["NRQTPARCMAXPERFACESS"],);
                $this->qtdMaxParcelasFactory->deleteQtdMaximaParcelasPerfilAcesso($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
