/* Sistemas Integrados TECNISA
   Servios

Nome: LIMPA_CONTA_FINANC

Descrio:  Apaga os registros do Contas a pagar e contas a receber

Criao:
18/04/2006 - Andr Rodrigo
*/

IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
              O.NAME = 'LIMPA_CONTA_FINANC' AND
              TYPE   = 'P' 	              AND
              U.UID  = O.UID                AND
              U.NAME = USER)

DROP PROCEDURE LIMPA_CONTA_FINANC
GO

CREATE PROCEDURE LIMPA_CONTA_FINANC
   @P_CDFILIAL    VARCHAR(4),
   @P_NRLANCTONF  VARCHAR(10),
   @P_DTLIMITE    DATETIME,
   @P_EXCLUSAOOK  VARCHAR(1) OUTPUT

AS

   DECLARE @V_CTCNTPAG               INTEGER;
   DECLARE @V_CTCNTREC               INTEGER;
   DECLARE @V_CTBOLFORA              INTEGER;
   DECLARE @V_CTBOLF                 INTEGER;
   DECLARE @V_CTERRO                 INTEGER;
   DECLARE @V_CTBAIXA                INTEGER;
   DECLARE @V_CTBOL                  INTEGER;

   DECLARE @V_BAIP_CDFILIAL          VARCHAR(4);
   DECLARE @V_BAIP_NRBAIXAPAG        VARCHAR(10);
   DECLARE @V_BAIP_DTBAIXAPAG        DATETIME;

   DECLARE @V_BAIR_CDFILIAL          VARCHAR(4);
   DECLARE @V_BAIR_NRBAIXAREC        VARCHAR(10);
   DECLARE @V_BAIR_DTBAIXAREC        DATETIME;
   DECLARE @V_CNTPAG_CDFILIAL        VARCHAR(4);
   DECLARE @V_CNTPAG_NRLANCTONF      VARCHAR(10);
   DECLARE @V_CNTPAG_NRSEQVENPAG     VARCHAR(2);
   DECLARE @V_CNTPAG_NRPARCELAPAG    VARCHAR(2);
   DECLARE @V_CNTPAG_CDFILIBPAG      VARCHAR(4);
   DECLARE @V_CNTPAG_NRLANBOLPAG     VARCHAR(10);

   DECLARE @V_C_BOLPAG_CDFILIAL      VARCHAR(4);
   DECLARE @V_C_BOLPAG_NRLANBOLPAG   VARCHAR(10);
   DECLARE @V_C_BOLPAG_CDFILIBAIPAG  VARCHAR(4);
   DECLARE @V_C_BOLPAG_NRBAIXAPAG    VARCHAR(10);

   DECLARE @V_CNTREC_CDFILIAL        VARCHAR(4);
   DECLARE @V_CNTREC_NRLANCTONF      VARCHAR(10);
   DECLARE @V_CNTREC_NRSEQVENREC     VARCHAR(2);
   DECLARE @V_CNTREC_NRPARCELAREC    VARCHAR(2);

   DECLARE @V_BOLREC_CDFILIAL        VARCHAR(4);
   DECLARE @V_BOLREC_NRLANBOLREC     VARCHAR(10);
   DECLARE @V_BOLREC_CDFILIBAIREC    VARCHAR(4);
   DECLARE @V_BOLREC_NRBAIXAREC      VARCHAR(10);
BEGIN
   SET @P_EXCLUSAOOK = 'S';

   /*************************************************************************/
   /*  VERIFICA SE AS CONTAS A PAGAR, BOLETOS E BAIXAS PODEM SER EXCLUDOS  */

   SELECT @V_CTCNTPAG = COUNT(CP.CDFILIAL)
   FROM  CONTAPAGAR CP
   WHERE CP.CDFILIAL     = @P_CDFILIAL
     AND CP.NRLANCTONF   = @P_NRLANCTONF;

   IF @V_CTCNTPAG > 0 BEGIN
      /* VERIFICA SE EXISTE BOLETO ACIMA DA DATA LIMITE */
      SELECT @V_CTBOLFORA = COUNT(*)
      FROM BOLETPAGAR BP, CONTAPAGAR CP
      WHERE CP.CDFILIAL    = @P_CDFILIAL
        AND CP.NRLANCTONF  = @P_NRLANCTONF
        AND BP.CDFILIAL    = CP.CDFILIBPAG
        AND BP.NRLANBOLPAG = CP.NRLANBOLPAG
        AND BP.DTVENBOLPAG > @P_DTLIMITE;

      /* VERIFICA SE EXISTE BAIXA ACIMA DA DATA LIMITE OU OUTROS BOLETOS ACIMA DA DATA LIGADOS A BAIXA*/
      SET @V_CTERRO = 0;
      DECLARE C_BAIP CURSOR FOR
      SELECT DISTINCT BA.CDFILIAL, BA.NRBAIXAPAG, BA.DTBAIXAPAG
      FROM BAIXAPAGA BA, BOLETPAGAR BP, CONTAPAGAR CP
      WHERE CP.CDFILIAL    = @P_CDFILIAL
        AND CP.NRLANCTONF  = @P_NRLANCTONF
        AND BP.CDFILIAL    = CP.CDFILIBPAG
        AND BP.NRLANBOLPAG = CP.NRLANBOLPAG
        AND BA.CDFILIAL    = BP.CDFILIBAIPAG
        AND BA.NRBAIXAPAG  = BP.NRBAIXAPAG;
      OPEN C_BAIP;
      FETCH NEXT FROM C_BAIP INTO @V_BAIP_CDFILIAL, @V_BAIP_NRBAIXAPAG, @V_BAIP_DTBAIXAPAG;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SELECT @V_CTBOLF = COUNT(*)
         FROM BOLETPAGAR
         WHERE CDFILIBAIPAG = @V_BAIP_CDFILIAL
           AND NRBAIXAPAG   = @V_BAIP_NRBAIXAPAG
           AND DTVENBOLPAG  > @P_DTLIMITE;

         IF (@V_CTBOLF > 0) OR
            (@V_BAIP_DTBAIXAPAG > @P_DTLIMITE) BEGIN
            SET @V_CTERRO = @V_CTERRO + 1;
         END;

         FETCH NEXT FROM C_BAIP INTO @V_BAIP_CDFILIAL, @V_BAIP_NRBAIXAPAG, @V_BAIP_DTBAIXAPAG;
      END;
      CLOSE C_BAIP;
      DEALLOCATE C_BAIP;

      IF (@V_CTBOLFORA > 0) OR (@V_CTERRO > 0) BEGIN
         SET @P_EXCLUSAOOK = 'N';
      END;
   END;

   /*************************************************************************/
   /*  VERIFICA SE AS CONTAS A RECEBER, BOLETOS E BAIXAS PODEM SER EXCLUDOS  */

   SELECT @V_CTCNTREC = COUNT(CDFILIAL)
   FROM  CONTARECEBER
   WHERE CDFILIAL   = @P_CDFILIAL
     AND NRLANCTONF = @P_NRLANCTONF;

   IF @V_CTCNTREC > 0 BEGIN
      /* VERIFICA SE EXISTE BOLETO ACIMA DA DATA LIMITE */
      SELECT @V_CTBOLFORA = COUNT(*)
      FROM BOLETRECEBER BR, CONTARECEBER CR
      WHERE CR.CDFILIAL    = @P_CDFILIAL
        AND CR.NRLANCTONF  = @P_NRLANCTONF
        AND BR.CDFILIAL    = CR.CDFILIBOLREC
        AND BR.NRLANBOLREC = CR.NRLANBOLREC
        AND BR.DTVENBOLREC > @P_DTLIMITE;

      /* VERIFICA SE EXISTE BAIXA ACIMA DA DATA LIMITE OU OUTROS BOLETOS ACIMA DA DATA LIGADOS A BAIXA*/
      SET @V_CTERRO = 0;
      DECLARE C_BAIR CURSOR FOR
      SELECT DISTINCT BA.CDFILIAL, BA.NRBAIXAREC, BA.DTBAIXAREC
      FROM BAIXARECEBIDA BA, BOLETRECEBER BR, CONTARECEBER CR
      WHERE CR.CDFILIAL    = @P_CDFILIAL
        AND CR.NRLANCTONF  = @P_NRLANCTONF
        AND BR.CDFILIAL    = CR.CDFILIBOLREC
        AND BR.NRLANBOLREC = CR.NRLANBOLREC
        AND BA.CDFILIAL    = BR.CDFILIBAIREC
        AND BA.NRBAIXAREC  = BR.NRBAIXAREC;
      OPEN C_BAIR;
      FETCH NEXT FROM C_BAIR INTO @V_BAIR_CDFILIAL, @V_BAIR_NRBAIXAREC, @V_BAIR_DTBAIXAREC;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SELECT @V_CTBOLF = COUNT(*)
         FROM BOLETRECEBER
         WHERE CDFILIBAIREC = @V_BAIR_CDFILIAL
           AND NRBAIXAREC   = @V_BAIR_NRBAIXAREC
           AND DTVENBOLREC  > @P_DTLIMITE;

         IF (@V_CTBOLF > 0) OR
            (@V_BAIR_DTBAIXAREC > @P_DTLIMITE) BEGIN
            SET @V_CTERRO = @V_CTERRO + 1;
         END;
      END;

      IF (@V_CTBOLFORA > 0) OR (@V_CTERRO > 0) BEGIN
         SET @P_EXCLUSAOOK = 'N';
      END;
   END;

   /*************************************************************************/
   /*  EXCLUI AS CONTAS A PAGAR E RECEBER DA NOTA FISCAL */

   IF @P_EXCLUSAOOK = 'S' BEGIN

      IF @V_CTCNTPAG > 0 BEGIN
        /*  EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTPAGAR DISABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETPAG DISABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXPAGAR DISABLE';  */

          DECLARE C_CNTPAG CURSOR FOR
          SELECT
             CDFILIAL,     NRLANCTONF,  NRSEQVENPAG,
             NRPARCELAPAG, CDFILIBPAG,  NRLANBOLPAG
          FROM CONTAPAGAR
          WHERE CDFILIAL    = @P_CDFILIAL
            AND NRLANCTONF  = @P_NRLANCTONF;
          OPEN C_CNTPAG;
          FETCH NEXT FROM C_CNTPAG INTO @V_CNTPAG_CDFILIAL,     @V_CNTPAG_NRLANCTONF, @V_CNTPAG_NRSEQVENPAG,
                                        @V_CNTPAG_NRPARCELAPAG, @V_CNTPAG_CDFILIBPAG, @V_CNTPAG_NRLANBOLPAG;

          WHILE (@@FETCH_STATUS = 0) BEGIN
             DELETE FROM AJCTPAGAR
             WHERE (CDFILIAL     = @V_CNTPAG_CDFILIAL)
               AND (NRLANCTONF   = @V_CNTPAG_NRLANCTONF)
               AND (NRSEQVENPAG  = @V_CNTPAG_NRSEQVENPAG)
               AND (NRPARCELAPAG = @V_CNTPAG_NRPARCELAPAG);

             DELETE FROM ADIANTAPAGAR
             WHERE (CDFILIAL     = @V_CNTPAG_CDFILIAL)
               AND (NRLANCTONF   = @V_CNTPAG_NRLANCTONF)
               AND (NRSEQVENPAG  = @V_CNTPAG_NRSEQVENPAG)
               AND (NRPARCELAPAG = @V_CNTPAG_NRPARCELAPAG);

             DELETE FROM CONTAPAGAR
             WHERE (CDFILIAL     = @V_CNTPAG_CDFILIAL)
               AND (NRLANCTONF   = @V_CNTPAG_NRLANCTONF)
               AND (NRSEQVENPAG  = @V_CNTPAG_NRSEQVENPAG)
               AND (NRPARCELAPAG = @V_CNTPAG_NRPARCELAPAG);

             DECLARE C_BOLPAG CURSOR FOR
             SELECT BP.CDFILIAL, BP.NRLANBOLPAG, BP.CDFILIBAIPAG, BP.NRBAIXAPAG
             FROM BOLETPAGAR BP, CONTAPAGAR CP
             WHERE CP.CDFILIAL     = @P_CDFILIAL
               AND CP.NRLANCTONF   = @P_NRLANCTONF
               AND BP.CDFILIAL     = CP.CDFILIBPAG
               AND BP.NRLANBOLPAG  = CP.NRLANBOLPAG;
             OPEN C_BOLPAG;
             FETCH NEXT FROM C_BOLPAG INTO @V_C_BOLPAG_CDFILIAL,     @V_C_BOLPAG_NRLANBOLPAG, @V_C_BOLPAG_CDFILIBAIPAG,
                                           @V_C_BOLPAG_NRBAIXAPAG;

             WHILE (@@FETCH_STATUS = 0) BEGIN
                SELECT @V_CTBOL = COUNT(*)
                FROM CONTAPAGAR
                WHERE CDFILIBPAG  = @V_C_BOLPAG_CDFILIAL
                  AND NRLANBOLPAG = @V_C_BOLPAG_NRLANBOLPAG;

                IF @V_CTBOL = 0 BEGIN
                   DELETE FROM AJBOLPAG
                   WHERE (CDFILIAL    = @V_C_BOLPAG_CDFILIAL)
                     AND (NRLANBOLPAG = @V_C_BOLPAG_NRLANBOLPAG);

                   DELETE FROM BOLETPAGAR
                   WHERE (CDFILIAL    = @V_C_BOLPAG_CDFILIAL)
                     AND (NRLANBOLPAG = @V_C_BOLPAG_NRLANBOLPAG);
                END;

                SELECT @V_CTBAIXA = COUNT(*)
                FROM BOLETPAGAR
                WHERE CDFILIBAIPAG = @V_C_BOLPAG_CDFILIBAIPAG
                  AND NRBAIXAPAG   = @V_C_BOLPAG_NRBAIXAPAG;

                IF @V_CTBAIXA = 0 BEGIN
                   DELETE FROM TPPAGBAIXA
                   WHERE CDFILIAL   = @V_C_BOLPAG_CDFILIBAIPAG
                     AND NRBAIXAPAG = @V_C_BOLPAG_NRBAIXAPAG;

                   DELETE FROM BAIXAPAGA
                   WHERE CDFILIAL   = @V_C_BOLPAG_CDFILIBAIPAG
                     AND NRBAIXAPAG = @V_C_BOLPAG_NRBAIXAPAG;
                END;

                FETCH NEXT FROM C_BOLPAG INTO @V_C_BOLPAG_CDFILIAL,     @V_C_BOLPAG_NRLANBOLPAG, @V_C_BOLPAG_CDFILIBAIPAG,
                                              @V_C_BOLPAG_NRBAIXAPAG;
             END;

             FETCH NEXT FROM C_CNTPAG INTO @V_CNTPAG_CDFILIAL,     @V_CNTPAG_NRLANCTONF, @V_CNTPAG_NRSEQVENPAG,
                                           @V_CNTPAG_NRPARCELAPAG, @V_CNTPAG_CDFILIBPAG, @V_CNTPAG_NRLANBOLPAG;
          END;

       /*   EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTPAGAR ENABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETPAG ENABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXPAGAR ENABLE'; */
      END;

      IF @V_CTCNTREC > 0 BEGIN
      /*   EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTRECEBER DISABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETREC DISABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXRECEBER DISABLE'; */

         DECLARE C_CNTREC CURSOR FOR
         SELECT CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC
         FROM CONTARECEBER
         WHERE CDFILIAL    = @P_CDFILIAL
           AND NRLANCTONF  = @P_NRLANCTONF;
         OPEN C_CNTREC;
         FETCH NEXT FROM C_CNTREC INTO @V_CNTREC_CDFILIAL,     @V_CNTREC_NRLANCTONF, @V_CNTREC_NRSEQVENREC,
                                       @V_CNTREC_NRPARCELAREC;

         WHILE (@@FETCH_STATUS = 0) BEGIN
            DELETE FROM AJCTRECEBER
            WHERE (CDFILIAL     = @V_CNTREC_CDFILIAL)
              AND (NRLANCTONF   = @V_CNTREC_NRLANCTONF)
              AND (NRSEQVENREC  = @V_CNTREC_NRSEQVENREC)
              AND (NRPARCELAREC = @V_CNTREC_NRPARCELAREC);

            DELETE FROM PARCELAVENDA
            WHERE (CDFILIAL     = @V_CNTREC_CDFILIAL)
              AND (NRLANCTONF   = @V_CNTREC_NRLANCTONF)
              AND (NRSEQVENREC  = @V_CNTREC_NRSEQVENREC)
              AND (NRPARCELAREC = @V_CNTREC_NRPARCELAREC);

            DELETE FROM CONTARECEBER
            WHERE (CDFILIAL     = @V_CNTREC_CDFILIAL)
              AND (NRLANCTONF   = @V_CNTREC_NRLANCTONF)
              AND (NRSEQVENREC  = @V_CNTREC_NRSEQVENREC)
              AND (NRPARCELAREC = @V_CNTREC_NRPARCELAREC);

            DECLARE C_BOLREC CURSOR FOR
            SELECT BR.CDFILIAL, BR.NRLANBOLREC, BR.CDFILIBAIREC, BR.NRBAIXAREC
            FROM BOLETRECEBER BR, CONTARECEBER CR
            WHERE CR.CDFILIAL    = @P_CDFILIAL
              AND CR.NRLANCTONF  = @P_NRLANCTONF
              AND BR.CDFILIAL    = CR.CDFILIBOLREC
              AND BR.NRLANBOLREC = CR.NRLANBOLREC
              AND BR.DTVENBOLREC <= @P_DTLIMITE;
            OPEN C_BOLREC;
            FETCH NEXT FROM C_BOLREC INTO @V_BOLREC_CDFILIAL,   @V_BOLREC_NRLANBOLREC, @V_BOLREC_CDFILIBAIREC,
                                          @V_BOLREC_NRBAIXAREC;

            WHILE (@@FETCH_STATUS = 0) BEGIN
               SELECT @V_CTBOL = COUNT(*) 
               FROM CONTARECEBER
               WHERE CDFILIBOLREC = @V_BOLREC_CDFILIAL
                 AND NRLANBOLREC  = @V_BOLREC_NRLANBOLREC;

               IF @V_CTBOL = 0 BEGIN
                  DELETE FROM AJBOLREC
                  WHERE (CDFILIAL    = @V_BOLREC_CDFILIAL)
                    AND (NRLANBOLREC = @V_BOLREC_NRLANBOLREC);

                  DELETE FROM BOLETRECEBER
                  WHERE (CDFILIAL    = @V_BOLREC_CDFILIAL)
                    AND (NRLANBOLREC = @V_BOLREC_NRLANBOLREC);
               END;

               SELECT @V_CTBAIXA = COUNT(*)
               FROM BOLETRECEBER
               WHERE CDFILIBAIREC = @V_BOLREC_CDFILIBAIREC
                 AND NRBAIXAREC   = @V_BOLREC_NRBAIXAREC;

               IF @V_CTBAIXA = 0 BEGIN
                  DELETE FROM TPRECBAIXA
                  WHERE CDFILIAL   = @V_BOLREC_CDFILIBAIREC
                    AND NRBAIXAREC = @V_BOLREC_NRBAIXAREC;

                  DELETE FROM BAIXARECEBIDA
                  WHERE CDFILIAL   = @V_BOLREC_CDFILIBAIREC
                    AND NRBAIXAREC = @V_BOLREC_NRBAIXAREC;
               END;

               FETCH NEXT FROM C_BOLREC INTO @V_BOLREC_CDFILIAL,     @V_BOLREC_NRLANBOLREC, @V_BOLREC_CDFILIBAIREC,
                                             @V_BOLREC_NRBAIXAREC;
            END;

            FETCH NEXT FROM C_CNTREC INTO @V_CNTREC_CDFILIAL,     @V_CNTREC_NRLANCTONF, @V_CNTREC_NRSEQVENREC,
                                          @V_CNTREC_NRPARCELAREC;
         END;

      /*   EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTRECEBER ENABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETREC ENABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXRECEBER ENABLE';  */
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LIMPA_CONTA_FINANC','5.05.012';
GO

